==> openmetadata_ingestion-1.5.7.1.dev0.tar.gz: openmetadata_ingestion-1.5.7.1.dev0/src/metadata/ingestion/source/pipeline/kafkaconnect/connection.py <==
#  Copyright 2021 Collate
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#  http://www.apache.org/licenses/LICENSE-2.0
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

"""
Source connection handler
"""

from typing import Optional

from metadata.generated.schema.entity.automations.workflow import (
    Workflow as AutomationWorkflow,
)
from metadata.generated.schema.entity.services.connections.pipeline.kafkaConnectConnection import (
    KafkaConnectConnection,
)
from metadata.ingestion.connections.test_connections import test_connection_steps
from metadata.ingestion.ometa.ometa_api import OpenMetadata
from metadata.ingestion.source.pipeline.kafkaconnect.client import KafkaConnectClient


def get_connection(connection: KafkaConnectConnection) -> KafkaConnectClient:
    """
    Create connection
    """
    return KafkaConnectClient(connection)


def test_connection(
    metadata: OpenMetadata,
    client: KafkaConnectClient,
    service_connection: KafkaConnectConnection,
    automation_workflow: Optional[AutomationWorkflow] = None,
) -> None:
    """
    Test connection. This can be executed either as part
    of a metadata workflow or during an Automation Workflow
    """

    test_fn = {
        "GetClusterInfo": client.get_cluster_info,
        "GetPipelines": client.get_connectors,
        "GetPlugins": client.get_connector_plugins,
    }

    test_connection_steps(
        metadata=metadata,
        test_fn=test_fn,
        service_type=service_connection.type.value,
        automation_workflow=automation_workflow,
    )

==> openmetadata_ingestion-1.6.7.3.dev0.tar.gz: openmetadata_ingestion-1.6.7.3.dev0/src/metadata/ingestion/source/pipeline/kafkaconnect/connection.py <==
#  Copyright 2021 Collate
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#  http://www.apache.org/licenses/LICENSE-2.0
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

"""
Source connection handler
"""

from typing import Optional

from metadata.generated.schema.entity.automations.workflow import (
    Workflow as AutomationWorkflow,
)
from metadata.generated.schema.entity.services.connections.pipeline.kafkaConnectConnection import (
    KafkaConnectConnection,
)
from metadata.generated.schema.entity.services.connections.testConnectionResult import (
    TestConnectionResult,
)
from metadata.ingestion.connections.test_connections import test_connection_steps
from metadata.ingestion.ometa.ometa_api import OpenMetadata
from metadata.ingestion.source.pipeline.kafkaconnect.client import KafkaConnectClient
from metadata.utils.constants import THREE_MIN


def get_connection(connection: KafkaConnectConnection) -> KafkaConnectClient:
    """
    Create connection
    """
    return KafkaConnectClient(connection)


def test_connection(
    metadata: OpenMetadata,
    client: KafkaConnectClient,
    service_connection: KafkaConnectConnection,
    automation_workflow: Optional[AutomationWorkflow] = None,
    timeout_seconds: Optional[int] = THREE_MIN,
) -> TestConnectionResult:
    """
    Test connection. This can be executed either as part
    of a metadata workflow or during an Automation Workflow
    """

    test_fn = {
        "GetClusterInfo": client.get_cluster_info,
        "GetPipelines": client.get_connectors_list,
        "GetPlugins": client.get_connector_plugins,
    }

    return test_connection_steps(
        metadata=metadata,
        test_fn=test_fn,
        service_type=service_connection.type.value,
        automation_workflow=automation_workflow,
        timeout_seconds=timeout_seconds,
    )
